@@ -3,7 +3,7 @@ import pathlib
 from amino.typecheck import boot
 from amino.maybe import Maybe, Just, Empty, may, flat_may, Nothing
 from amino.either import Left, Right, Either
-from amino.list import List, Lists
+from amino.list import List, Lists, Nil
 from amino.boolean import Boolean
 from amino.anon.boot import __, L, _
 from amino.lazy_list import LazyList
@@ -11,8 +11,8 @@ from amino.map import Map
 from amino.future import Future
 from amino.func import curried, I
 from amino.env_vars import env
-from amino.task import Try, Task, IO
-from amino.logging import Logger, log
+from amino.io import Try, IO
+from amino.logging import Logger, amino_root_logger as amino_log
 from amino.eff import Eff
 from amino.eval import Eval
 from amino.regex import Regex
@@ -25,5 +25,5 @@ Path = pathlib.Path
 boot()
 
 __all__ = ('Maybe', 'Just', 'Empty', 'may', 'List', 'Map', '_', 'Future', 'Boolean', 'development', 'flat_may',
-           'curried', '__', 'Left', 'Right', 'Either', 'env', 'Try', 'LazyList', 'Logger', 'log', 'I', 'L', 'Eff',
-           'Task', 'Eval', 'Regex', 'Nothing', 'integration_test', 'Lists', 'do', 'IO', 'Id')
+           'curried', '__', 'Left', 'Right', 'Either', 'env', 'Try', 'LazyList', 'Logger', 'I', 'L', 'Eff',
+           'IO', 'Eval', 'Regex', 'Nothing', 'integration_test', 'Lists', 'do', 'IO', 'Id', 'Nil', 'amino_log')
